@@ -164,7 +164,7 @@ class Store(StorageInterface):
 
         query = self.environ.get('tiddlyweb.query', {})
         try:
-            slice_index = query['index'][0]
+            slice_index = int(query['index'][0])
             del query['index']
         except KeyError:
             slice_index = 0
